<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/
/*Translated to Brazilian by: Luiz Gustavo Aleagi Nunes - tatau           */
/*For any comments/suggestions: aleagi@terra.com.br			        */
/**************************************************************************/

define("_CATEGORY","Categoria");
define("_CATEGORIES","Categorias");
define("_FAQ2","FAQ (Perguntas frequentes)");
define("_BACKTOTOP","Voltar ao TOP");
define("_BACKTOFAQINDEX","Voltar ao ndice do FAQ");
define("_MAIN","ndice");
define("_QUESTION","Pergunta");
define("_ANSWER","Resposta");

?>